Learn R Programming

CNVrd2 (version 1.10.2)

CNVrd2-package: CNVrd2

Description

CNVrd2 uses next-generation sequencing data to measure human gene copy number for multiple samples and indentify SNPs/INDELs which are in linkage disequilibrium with the gene copy number variation.

Arguments

Details

Package:
CNVrd2
Type:
Package
Version:
1.0
Date:
2013-03-26
License:
GPL-2
Depends:
methods